pub async fn list_conversations(__arg0: State<Arc<Node>>) -> impl IntoResponseExpand description
Lists all conversations, including the last message and online status of friends.
pub async fn list_conversations(__arg0: State<Arc<Node>>) -> impl IntoResponseLists all conversations, including the last message and online status of friends.